@@ -42,17 +42,17 @@ class DownloadVideo:
         filename = "%s.%s" % (filename, fname.rsplit('.', 1)[1]) if filename else fname
         filepath = os.path.join(folder, filename)
         response = requests.get(url, stream=True)
-        if response.status_code == 200:
-            content_length = int(response.headers.get("Content-Length"))
-            file_length = len(response.content)
-            if content_length != file_length:
-                raise VideoNotDownload(
-                    'Broken file "%s" (Content-length=%s, but file length=%s)'
-                    % (filepath, content_length, file_length)
-                )
-            with open(filepath, "wb") as f:
-                f.write(response.content)
-                f.close()
+        response.raise_for_status()
+        content_length = int(response.headers.get("Content-Length"))
+        file_length = len(response.content)
+        if content_length != file_length:
+            raise VideoNotDownload(
+                'Broken file "%s" (Content-length=%s, but file length=%s)'
+                % (filepath, content_length, file_length)
+            )
+        with open(filepath, "wb") as f:
+            f.write(response.content)
+            f.close()
         return os.path.abspath(filepath)
 
 
